<?php
/**
 * Cart Page
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/cart/cart.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author  WooThemes
 * @package WooCommerce/Templates
 * @version 3.5.0
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

global $woocommerce;

do_action( 'woocommerce_before_cart' ); ?>

<form class="woocommerce-cart-form" action="<?php echo esc_url( wc_get_cart_url() ); ?>" method="post">
    <?php wp_nonce_field( 'woocommerce-cart', 'woocommerce-cart-nonce' ); ?>
	<div class="span9">
        <?php do_action( 'woocommerce_before_cart_table' ); ?>

        <table class="shop_table shop_table_responsive cart woocommerce-cart-form__contents" cellspacing="0">
            <thead>
                <tr><th colspan="6"><h2><?php _e( 'Shopping Cart', 'yit' ); ?></h2></th></tr>
            <tr>
                <th class="product-remove">&nbsp;</th>
                <th class="product-thumbnail">&nbsp;</th>
                <th class="product-name"><?php _e( 'Product', 'yit' ); ?></th>
                <th class="product-price"><?php _e( 'Price', 'yit' ); ?></th>
                <th class="product-quantity"><?php _e( 'Quantity', 'yit' ); ?></th>
                <th class="product-subtotal"><?php _e( 'Total', 'yit' ); ?></th>
            </tr>
            </thead>
            <tbody>
            <?php do_action( 'woocommerce_before_cart_contents' ); ?>

            <?php
            if ( sizeof( WC()->cart->get_cart() ) > 0 ) {
                foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
                    $_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
                    $product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

                    if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
                        $product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
                        ?>
                        <tr class="<?php echo esc_attr( apply_filters( 'woocommerce_cart_item_class', 'cart_item', $cart_item, $cart_item_key ) ); ?>">
                            <!-- Remove from cart link -->
                            <td class="product-remove">
                                <?php
                                echo apply_filters( 'woocommerce_cart_item_remove_link', sprintf('<a href="%s" class="remove" title="%s">&times;</a>', esc_url( wc_get_cart_remove_url( $cart_item_key ) ), __( 'Remove this item', 'yit' ) ), $cart_item_key );
                                ?>
                            </td>

                            <!-- The thumbnail -->
                            <td class="product-thumbnail">
                                <?php
                                $thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );

                                if ( ! $product_permalink ) {
                                    echo wp_kses_post($thumbnail);
                                } else {
                                    printf( '<a href="%s">%s</a>', esc_url( $product_permalink ), wp_kses_post($thumbnail) );
                                }
                                ?>
                            </td>

                            <!-- Product Name -->
                            <td class="product-name" data-title="<?php _e( 'Product', 'yit' ); ?>">
                                <?php
                                if ( ! $product_permalink ) {
                                    echo wp_kses_post(apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;');
                                } else {
                                    echo wp_kses_post(apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $_product->get_name() ), $cart_item, $cart_item_key ));
                                }

                                // Meta data
                                echo wc_get_formatted_cart_item_data( $cart_item ); // PHPCS: XSS ok.

                                // Backorder notification
                                if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) )

                                echo wp_kses_post( apply_filters( 'woocommerce_cart_item_backorder_notification', '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'yit' ) . '</p>', $product_id ) );
                                ?>
                            </td>

                            <!-- Product price -->
                            <td class="product-price" data-title="<?php _e( 'Price', 'woocommerce' ); ?>">
                                <?php
                                echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key ); // PHPCS: XSS ok.
                                ?>
                            </td>

                            <!-- Quantity inputs -->
                            <td class="product-quantity" data-title="<?php _e( 'Quantity', 'yit' ); ?>">
                                <?php
                                if ( $_product->is_sold_individually() ) {
                                    $product_quantity = sprintf( '1 <input type="hidden" name="cart[%s][qty]" value="1" />', $cart_item_key );
                                }  else {
                                    $step	= apply_filters( 'woocommerce_quantity_input_step', '1', $_product );
                                    $min 	= apply_filters( 'woocommerce_quantity_input_min', '', $_product );
                                    $max 	= apply_filters( 'woocommerce_quantity_input_max', $_product->backorders_allowed() ? '' : $_product->get_stock_quantity(), $_product );

                                    $product_quantity = sprintf( '<div class="quantity"><input type="number" name="cart[%s][qty]" step="%s" min="%s" max="%s" value="%s" size="4" title="' . _x( 'Qty', 'Product quantity input tooltip', 'yit' ) . '" class="input-text qty text" maxlength="12" /></div>', $cart_item_key, $step, $min, $max, esc_attr( $cart_item['quantity'] ) );
                                }
                            
                                echo apply_filters( 'woocommerce_cart_item_quantity', $product_quantity, $cart_item_key ); // PHPCS: XSS ok.
                                ?>
                            </td>

                            <!-- Product subtotal -->
                            <td class="product-subtotal">
                                <?php
                                echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key );
                                ?>
                            </td>
                        </tr>
                    <?php
                    }
                }
            }

            do_action( 'woocommerce_cart_contents' );
            ?>

            <?php do_action( 'woocommerce_after_cart_contents' ); ?>
            </tbody>
        </table>

        <div class="row-fluid">
            <div class="span12">
                <?php if ( wc_coupons_enabled() ) : ?>
                     <div class="cart-collaterals">
                        <h2><?php _e( 'Coupon', 'yit' ); ?></h2>
                        <p class="form-row form-row-wide">
                        <input type="text" name="coupon_code" class="input-text" id="coupon_code" value="" placeholder="<?php esc_attr_e( 'Coupon code', 'woocommerce' ); ?>" />
                        </p>
                        <p class="form-row form-row-wide">
                            <input type="submit" class="button" name="apply_coupon" value="<?php esc_attr_e( 'Apply coupon', 'yit' ); ?>" />
                         </p>
                        <?php do_action('woocommerce_cart_coupon'); ?>

                    </div>
                <?php endif ?>
            </div>
        </div>

        <?php do_action( 'woocommerce_after_cart_table' ); ?>
    </div>
    <div class="span3">
         <div class="cart-collaterals">
            <?php do_action('woocommerce_cart_collaterals'); ?>
        </div>
    </div>
</form>

<div class="span9">
    <?php woocommerce_shipping_calculator(); ?>
</div>

    <div class="row-fluid">
        <div class="span12">
            <?php woocommerce_cross_sell_display(); ?>
        </div>
    </div>

<?php do_action( 'woocommerce_after_cart' ); ?>